Column compression algorithms.
Supports constant, one-value, boolean, integer bitpacking, string dictionary, float, and list delta compression.
Structs
- Compressed
Chunk - A compressed column chunk.
Enums
Functions
- compress
- Compress a byte slice using the given algorithm.
- compress_
float - Float compression: uses integer bitpacking on delta/offset representations. Format: [value_size: u8][num_values: u32][strategy: u8][payload]
- compress_
integer_ bitpacking - Integer bitpacking compression for a batch of values. Format: [value_size: u8][num_values: u32][packed_values…] Each packed value is [used_bytes: u8][significant_bytes…]
- compress_
serialized_ value - Compress a single serialized value.
- decompress
- Decompress a chunk back to raw bytes.
- decompress_
serialized_ value - Decompress a single serialized value.
- serialized_
value_ size - Determine the byte size of a serialized primitive value based on its physical type. Used to know how many bytes to expect for compression.