pub struct GroupCommit<W: WalLike> { /* private fields */ }Expand description
Leader/follower group-commit coordinator over a shared WalLike target.
Implementations
Sourceimpl<W: WalLike> GroupCommit<W>
impl<W: WalLike> GroupCommit<W>
Sourcepub fn new(wal: Arc<W>, config: GroupCommitConfig) -> Self
pub fn new(wal: Arc<W>, config: GroupCommitConfig) -> Self
Create a coordinator over wal with the given config.
pub fn config(&self) -> &GroupCommitConfig
Sourcepub fn stats(&self) -> GroupCommitStats
pub fn stats(&self) -> GroupCommitStats
Current cumulative statistics.
Sourcepub fn flush(&self) -> Result<GroupCommitResult>
pub fn flush(&self) -> Result<GroupCommitResult>
Wait for a durable flush of everything appended so far.
Enqueues this submission, then either leads this group or waits for a leader to include it. Returns once an fsync that started after the enqueue has completed.