pub struct GroupCommitConfig {
pub enabled: bool,
pub drain_timeout: Duration,
pub leader_timeout: Duration,
}Expand description
Group-commit configuration.
Fields
enabled: boolMaster switch; when false callers should fall back to an inline
fsync (the coordinator itself is inert about the flag).
drain_timeout: DurationWindow a leader keeps collecting submissions before fsyncing.
leader_timeout: DurationHow long a follower waits before attempting to take over leadership.