Module node_group

Module node_group 

NodeGroup — a fixed-size collection of ColumnChunks (one per column).

A NodeGroup holds up to NODE_GROUP_SIZE rows of data across all columns of a table. When the group is full it can be flushed to a set of persistent Column instances. This mirrors the C++ Akar ChunkedNodeGroup / NodeGroup concept.

Row → Column mapping

Each row is a Vec<Value> with one element per column. The NodeGroup distributes values column-wise: columns[col_idx].append(values[col_idx]).

Structs

NodeGroup
A node group stores up to NODE_GROUP_SIZE rows in columnar format.