pub struct FileHandle {
pub path: PathBuf,
pub num_pages: u64,
pub page_size: usize,
pub free_space_manager: Option<Arc<FreeSpaceManager>>,
}Expand description
A file handle mapping logical page numbers to file offsets.
Fields
path: PathBufPath to the database file.
num_pages: u64Number of pages currently in the file.
page_size: usizePage size in bytes.
free_space_manager: Option<Arc<FreeSpaceManager>>Free space manager for reusing pages.
Implementations
Sourceimpl FileHandle
impl FileHandle
pub fn new(path: PathBuf, page_size: usize) -> Self
pub fn with_free_space_manager(self, fsm: Arc<FreeSpaceManager>) -> Self
Sourcepub fn page_offset(&self, page_num: PageNum) -> u64
pub fn page_offset(&self, page_num: PageNum) -> u64
Get the file offset for a given page number.
Sourcepub fn allocate_page(&mut self) -> PageNum
pub fn allocate_page(&mut self) -> PageNum
Allocate a new page (extend the file or reuse from FSM).
Sourcepub fn extend_file(&mut self, num_pages: u64) -> Result<PageNum>
pub fn extend_file(&mut self, num_pages: u64) -> Result<PageNum>
Extend the file by num_pages pages, writing zero-filled data.
Returns the starting page number of the newly extended region.