check_zone_map

Function check_zone_map 

pub fn check_zone_map(
    stats: &ColumnChunkStats,
    op: &str,
    constant: &Value,
) -> ZoneMapCheckResult
Check whether a column chunk with the given stats can be skipped based on a predicate (column op constant).

Returns SkipScan if the chunk definitely doesn’t match.