pub struct RoaringBitmap { /* private fields */ }Expand description
A compressed bitset for u32 values using the Roaring Bitmap format.
Example
use akar_storage::roaring_bitmap::RoaringBitmap;
let mut rb = RoaringBitmap::new();
rb.add(42);
rb.add(100000);
assert!(rb.contains(42));
assert!(!rb.contains(0));
assert_eq!(rb.len(), 2);Implementations
Sourceimpl RoaringBitmap
impl RoaringBitmap
Sourcepub fn from_sorted(values: &[u32]) -> Self
pub fn from_sorted(values: &[u32]) -> Self
Create a bitmap from a sorted Vec<u32>.
Sourcepub fn add(&mut self, value: u32) -> bool
pub fn add(&mut self, value: u32) -> bool
Insert a value. Returns true if the value was newly added.
Sourcepub fn remove(&mut self, value: u32) -> bool
pub fn remove(&mut self, value: u32) -> bool
Remove a value. Returns true if the value was present.
Sourcepub fn union_with(&mut self, other: &RoaringBitmap)
pub fn union_with(&mut self, other: &RoaringBitmap)
Union with another bitmap in-place.
Sourcepub fn intersect_with(&mut self, other: &RoaringBitmap)
pub fn intersect_with(&mut self, other: &RoaringBitmap)
Intersection with another bitmap in-place.
Sourcepub fn difference_with(&mut self, other: &RoaringBitmap)
pub fn difference_with(&mut self, other: &RoaringBitmap)
Difference with another bitmap in-place (self = self \ other).
Sourcepub fn union(&self, other: &RoaringBitmap) -> RoaringBitmap
pub fn union(&self, other: &RoaringBitmap) -> RoaringBitmap
Return a new bitmap as the union of self and other.
Sourcepub fn intersection(&self, other: &RoaringBitmap) -> RoaringBitmap
pub fn intersection(&self, other: &RoaringBitmap) -> RoaringBitmap
Return a new bitmap as the intersection of self and other.
Sourcepub fn difference(&self, other: &RoaringBitmap) -> RoaringBitmap
pub fn difference(&self, other: &RoaringBitmap) -> RoaringBitmap
Return a new bitmap as the difference of self and other.
Sourcepub fn iter(&self) -> RoaringIter<'_> ⓘ
pub fn iter(&self) -> RoaringIter<'_> ⓘ
Iterator over all values in sorted order.