pub trait WalLike: Send + Sync {
// Required method
fn flush_to_disk(&self) -> Result<()>;
}Expand description
A durable flush target that many commits can share.
For the WAL this maps to wal.flush_to_disk(), i.e. one fsync.
Required Methods
Sourcefn flush_to_disk(&self) -> Result<()>
fn flush_to_disk(&self) -> Result<()>
Durably persist all records appended to the target so far.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".