pub struct LocalTableData { /* private fields */ }Expand description
A local table insert/update buffer for an in-progress transaction.
Stores rows as serialised byte vectors (compatible with the Value binary
format used by Column). The flush_to_tables() method deserialises and
applies them.
Implementations
Sourceimpl LocalTableData
impl LocalTableData
pub fn new() -> Self
pub fn insert(&mut self, row_data: Vec<u8>)
pub fn delete(&mut self, row_id: u64)
pub fn update(&mut self, row_id: u64, row_data: Vec<u8>)
pub fn inserted_rows(&self) -> &[Vec<u8>]
pub fn deleted_row_ids(&self) -> &[u64]
pub fn updated_rows(&self) -> &HashMap<u64, Vec<u8>>
pub fn is_empty(&self) -> bool
Sourcepub fn flush_to_node_table(
&self,
table_id: u64,
node_table: &mut NodeTable,
txn_id: Option<u64>,
) -> Result<Vec<UndoRecord>, StorageError>
pub fn flush_to_node_table( &self, table_id: u64, node_table: &mut NodeTable, txn_id: Option<u64>, ) -> Result<Vec<UndoRecord>, StorageError>
Flush this table’s buffered data to a NodeTable, returning undo records.
Deserialises each buffered row from binary format and calls
node_table.insert_row_with_txn().
When txn_id is Some(...), inserts/deletes are recorded in VersionInfo.
Returns undo records so the caller can store them for potential rollback.
Sourcepub fn flush_to_rel_table(
&self,
rel_table: &mut RelTable,
) -> Result<(), StorageError>
pub fn flush_to_rel_table( &self, rel_table: &mut RelTable, ) -> Result<(), StorageError>
Flush this table’s buffered data to a RelTable.
pub fn clear(&mut self)